@@ -25,7 +25,7 @@ class ClusterPolicy(resource.Resource):
     allow_get = True
 
     _query_mapping = resource.QueryParameters(
-        'policy_name', 'policy_type', is_enabled='enabled')
+        'sort', 'policy_name', 'policy_type', is_enabled='enabled')
 
     # Properties
     #: ID of the policy object.
