@@ -18,13 +18,14 @@ from openstack.identity.v3 import group
 from openstack.identity.v3 import policy
 from openstack.identity.v3 import project
 from openstack.identity.v3 import region
+from openstack.identity.v3 import role
 from openstack.identity.v3 import service
 from openstack.identity.v3 import trust
 from openstack.identity.v3 import user
-from openstack.tests.unit import test_proxy_base
+from openstack.tests.unit import test_proxy_base2
 
 
-class TestIdentityProxy(test_proxy_base.TestProxyBase):
+class TestIdentityProxy(test_proxy_base2.TestProxyBase):
     def setUp(self):
         super(TestIdentityProxy, self).setUp()
         self.proxy = _proxy.Proxy(self.session)
@@ -242,3 +243,24 @@ class TestIdentityProxy(test_proxy_base.TestProxyBase):
 
     def test_region_update(self):
         self.verify_update(self.proxy.update_region, region.Region)
+
+    def test_role_create_attrs(self):
+        self.verify_create(self.proxy.create_role, role.Role)
+
+    def test_role_delete(self):
+        self.verify_delete(self.proxy.delete_role, role.Role, False)
+
+    def test_role_delete_ignore(self):
+        self.verify_delete(self.proxy.delete_role, role.Role, True)
+
+    def test_role_find(self):
+        self.verify_find(self.proxy.find_role, role.Role)
+
+    def test_role_get(self):
+        self.verify_get(self.proxy.get_role, role.Role)
+
+    def test_roles(self):
+        self.verify_list(self.proxy.roles, role.Role, paginated=False)
+
+    def test_role_update(self):
+        self.verify_update(self.proxy.update_role, role.Role)
