@@ -147,10 +147,14 @@ class TestConnection(base.TestCase):
                          conn.network.__class__.__module__)
         self.assertEqual('openstack.object_store.v1._proxy',
                          conn.object_store.__class__.__module__)
+        self.assertEqual('openstack.load_balancer.v2._proxy',
+                         conn.load_balancer.__class__.__module__)
         self.assertEqual('openstack.orchestration.v1._proxy',
                          conn.orchestration.__class__.__module__)
         self.assertEqual('openstack.telemetry.v2._proxy',
                          conn.telemetry.__class__.__module__)
+        self.assertEqual('openstack.workflow.v2._proxy',
+                         conn.workflow.__class__.__module__)
 
     def _prepare_test_config(self):
         # Create a temporary directory where our test config will live
